@@ -99,12 +99,14 @@ def get_config(dirname="data/postgresqlite"):
 
     config = Config(dirname)
 
-    if config.autostart:
-        _auto_start(config)
+    if not config.autostart:
+        return config
+
+    _auto_start(config)
 
     count = 0
     while True:
-        if config.autostart and not os.path.exists(config.expand_path(config.dir+"/locks/daemon.lock")):
+        if not os.path.exists(config.expand_path(config.dir+"/locks/daemon.lock")):
             print(f"\nPostgreSQL server failed to start - check {config.dir}/postgresqlite.log", file=sys.stderr)
             exit(1)
         try:
